#!/usr/bin/perl

use File::Basename;
use Image::ExifTool;
use Math::Spline;
my($exifTool) = new Image::ExifTool;

@x = (7.2, 8, 9, 10, 15, 18, 20, 25, 28.8);
@y = (100, 80, 46, 39, 9, 2, 2, 0, 0);
$spline = new Math::Spline(\@x, \@y);

foreach $i (@ARGV) {

	@extlist = ('\.RAF');

	($name, $dir, $ext) = fileparse($i, @extlist);

	$rafname = $name . $ext;
	$s7rname = $name . ".S7R";

	printf "RAF = %s\r\n", $rafname;
	printf "S7R = %s\r\n", $s7rname;

	my($exifInfo) = $exifTool->ImageInfo($rafname);
	my($len) = $exifInfo->{"FocalLength"};


	#my($lenscoef) = 144 - $len * 5;
	$lenscoef = $spline->evaluate($len);
	my($lenscoef16) = sprintf("%02X", $lenscoef);

	printf "Zoom = %2.1f mm, Lens coefficient = %d\r\n", $len, $lenscoef;

	open(OUT, "> " . $s7rname);
	
	print OUT "[Settings]\r\n";
	print OUT "version=71\r\n";
	print OUT "gamma=1.800000\r\n";
	print OUT "sensitize=0.000000\r\n";
	print OUT "whiteBalance=7\r\n";
	print OUT "wbTempt=5500\r\n";
	print OUT "contrast=0\r\n";
	print OUT "brightness=0\r\n";
	print OUT "saturation=125\r\n";
	print OUT "hue=0\r\n";
	print OUT "sharpness=0\r\n";
	print OUT "rotate=0\r\n";
	print OUT "gammaSR=1.000000\r\n";
	print OUT "gammaSR2=1.000000\r\n";
	print OUT "mixSR=80\r\n";
	print OUT "typeSR=5\r\n";
	print OUT "iEnhColor=0\r\n";
	print OUT "iEnhGreen=0\r\n";
	print OUT "iColorNR=1\r\n";
	print OUT "iColorNRthreshold=40\r\n";
	print OUT "soften=0\r\n";
	print OUT "harden=20\r\n";
	print OUT "ICC=0\r\n";
	print OUT "easySR=1\r\n";
	print OUT "linearSR=70\r\n";
	print OUT "bGammaLog=1\r\n";
	print OUT "bFreeCurve=0\r\n";
	print OUT "bNR=1\r\n";
	print OUT "NR1=1\r\n";
	print OUT "NR2=80\r\n";
	print OUT "NR3=100\r\n";
	print OUT "NR4=25\r\n";
	print OUT "customWBv=71\r\n";
	print OUT "customWB1=128\r\n";
	print OUT "customWB2=128\r\n";
	print OUT "customWB3=128\r\n";
	print OUT "WBfineTuneR=0\r\n";
	print OUT "WBfineTuneG=0\r\n";
	print OUT "WBfineTuneB=0\r\n";
	print OUT "WBfineTune=0\r\n";
	print OUT "UseRafWB=1\r\n";
	print OUT "DistorionSettings_flag=1\r\n";
	print OUT "DistorionSettings=" . $lenscoef16 . "00000000000000F8FFFFFF00000000000000000000000000000000C800000010\r\n";
	print OUT "FileName=" . $rafname . "\r\n";
	print OUT "CropAspectRatio=0\r\n";
	print OUT "CropSelect0.x=-1\r\n";
	print OUT "CropSelect0.y=-1\r\n";
	print OUT "CropSelect1.x=0\r\n";
	print OUT "CropSelect1.y=0\r\n";
	
	printf "finished.\r\n\r\n";
	
	close(OUT);

}

